==> release.12.2.28.1.tgz: cgi-cpn/lib_logproc.pm <==
#!/usr/bin/perl

# --------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# --------------------------------------------------------------
# Requiere
# use glib_hrfec_03;
# use glib_fildir_03;

use strict;
use utf8;
package lib_logproc;

our $JS_FILE = '';
our $LOG_FILE = '';
our $MODO_WEB = 0;
our $BD = undef;

# ---------------------------------------------------------------
# por motivos de cambios de interfaz de usuario, los parametros
# $title y $desc ya no se usan.
sub log_init {
    my $buffer = '<pre>';

    if (-f ($LOG_FILE)) {
        unlink $LOG_FILE;
    }
    glib_fildir_03::write_file($LOG_FILE, $buffer);
}

# ------------------------------------------------------------------------------
sub flush_log {
    # Abrir archivo log.
    if ($MODO_WEB) {
        my $buffer = glib_fildir_03::read_file($LOG_FILE);
        $buffer =~ s/<input .*?presione.*?refrescar.*?>//s;
        print $buffer;
    }
}

# ------------------------------------------------------------------------------
sub add_to_log {
    my $msg = "$_[0]<br>\n";

    # Abrir archivo log
    return unless($LOG_FILE);

    glib_fildir_03::append_file($LOG_FILE, $msg);

    print $msg if ($MODO_WEB);
}

# ------------------------------------------------------------------------------
sub add_to_log_count {
    my $msg = $_[0];
    return unless($msg);

    # Se calcula fecha / hora
    my $dtime = glib_hrfec_03::get_dtime_pack4();
    $dtime = &format_dtime($dtime);

    # Se actualiza fecha / hora con el mensaje
    my $newmsg = "$dtime\t$msg";
    &add_to_log($newmsg);
}

# ------------------------------------------------------------------------------
sub add_to_log_finish {
    my $msg = $_[0];
    my $do_exit = $_[1]; # 0 | 1
    my $newmsg;

    &add_to_log_count($msg);
    &writeRule();

    $newmsg = '</pre>';
    &add_to_log($newmsg);
    exit if ($do_exit == 1);
}

# -------------------------------------------------------------------------------------------------#
sub finishLoading {
    my ($msg, $total, $terminado) = ($_[0], $_[1], $_[2]);
    if ($total) {
        $msg = '{"status":1, "msg":"'.$msg.'", "total": "'.$total.'", "finish": '.$terminado.'}';
    } else {
        $msg = '{"status":1, "msg":"'.$msg.'", "total": "0", "finish": '.$terminado.'}';
    }
    print STDERR "finishLoading msg[$msg]\n";
    glib_fildir_03::write_file("$prontus_varglb::DIR_SERVER$JS_FILE", $msg);
}

# -------------------------------------------------------------------------------------------------#
sub updateStatus {
    my ($status, $msg, $terminado, $progress) = ($_[0], $_[1], $_[2], $_[3]);
    $msg = '{"status":'.$status.', "msg":"'.$msg.'", "finish": '.$terminado.', "progress": "'.$progress.'"}';
    # print STDERR "msg[$msg]\n";
    glib_fildir_03::write_file("$prontus_varglb::DIR_SERVER$JS_FILE", $msg);
}

# ------------------------------------------------------------------------------
sub handle_error {
    my ($msg, $ok_regs) = @_;
    my $newmsg;

    print STDERR "$msg\n";
    $ok_regs = '0' if($ok_regs eq '');
    &writeRule();
    &add_to_log_count("Ejecucion abortada: $msg.\n\tSe alcanzaron a procesar $ok_regs registros.");

    $newmsg = '</pre>';
    &add_to_log($newmsg);

    exit;
}

# ------------------------------------------------------------------------------
sub writeRule {
    my $msg = "----------------------------------------------------------------------";
    &add_to_log($msg);
}

# ------------------------------------------------------------------------------
sub format_dtime {
    my $dtime = $_[0];
    $dtime =~ /(\d\d\d\d)(\d\d)(\d\d)(\d\d)(\d\d)(\d\d)/;
    return "$3/$2/$1 - $4:$5:$6";
}

return 1;

==> release.12.3.1.2.tgz: cgi-cpn/lib_logproc.pm <==
#!/usr/bin/perl

# --------------------------------------------------------------
# Prontus CMS
# http://www.prontus.cl
# by Altavoz.net
#
# licensed under LGPL license.
# http://www.prontus.cl/license.html
# --------------------------------------------------------------
# Requiere
# use glib_hrfec_03;
# use glib_fildir_03;

use strict;
use utf8;
package lib_logproc;

our $JS_FILE = '';
our $LOG_FILE = '';

# ---------------------------------------------------------------
# por motivos de cambios de interfaz de usuario, los parametros
# $title y $desc ya no se usan.
sub log_init {
    my $buffer = '<pre>';

    if (-f ($LOG_FILE)) {
        unlink $LOG_FILE;
    }
    glib_fildir_03::write_file($LOG_FILE, $buffer);
}

# ------------------------------------------------------------------------------
sub add_to_log {
    my $msg = "$_[0]<br>\n";
    lib_stdlog::print_err($msg);
    # Abrir archivo log
    return unless($LOG_FILE);

    glib_fildir_03::append_file($LOG_FILE, $msg);
}

# ------------------------------------------------------------------------------
sub add_to_log_count {
    my $msg = $_[0];
    return unless($msg);

    # Se calcula fecha / hora
    my $dtime = glib_hrfec_03::get_dtime_pack4();
    $dtime = &format_dtime($dtime);

    # Se actualiza fecha / hora con el mensaje
    my $newmsg = "$dtime\t$msg";
    &add_to_log($newmsg);
}

# ------------------------------------------------------------------------------
sub add_to_log_finish {
    my $msg = $_[0];
    my $do_exit = $_[1]; # 0 | 1
    my $newmsg;

    &add_to_log_count($msg);
    &writeRule();

    $newmsg = '</pre>';
    &add_to_log($newmsg);
    exit if ($do_exit == 1);
}

# -------------------------------------------------------------------------------------------------#
sub finishLoading {
    my ($msg, $total, $terminado) = @_;

    my $resp;
    $resp->{'status'} = 1;
    $resp->{'msg'}    = $msg;
    $resp->{'total'}  = 0;

    if ($total) {
        $resp->{'total'} = $total;
    }
    if ($terminado) {
        $resp->{'finish'} = $terminado;
    }

    my $json = JSON::encode_json($resp);
    utf8::decode($json);

    lib_stdlog::print_err("finishLoading json[$json]\n");
    glib_fildir_03::write_file($JS_FILE, $json);
}

# -------------------------------------------------------------------------------------------------#
sub updateStatus {
    my ($status, $msg, $terminado, $progress) = ($_[0], $_[1], $_[2], $_[3]);
    $msg = '{"status":'.$status.', "msg":"'.$msg.'", "finish": '.$terminado.', "progress": "'.$progress.'"}';
    # lib_stdlog::print_err("msg[$msg]\n");
    glib_fildir_03::write_file($JS_FILE, $msg);
}

# ------------------------------------------------------------------------------
sub handle_error {
    my ($msg, $ok_regs) = @_;
    my $newmsg;

    lib_stdlog::print_err("$msg\n");
    $ok_regs = '0' if($ok_regs eq '');
    &writeRule();
    &add_to_log_count("Ejecucion abortada: $msg.\n\tSe alcanzaron a procesar $ok_regs registros.");

    $newmsg = '</pre>';
    &add_to_log($newmsg);

    exit;
}

# ------------------------------------------------------------------------------
sub writeRule {
    my $msg = "----------------------------------------------------------------------";
    &add_to_log($msg);
}

# ------------------------------------------------------------------------------
sub format_dtime {
    my $dtime = $_[0];
    $dtime =~ /(\d\d\d\d)(\d\d)(\d\d)(\d\d)(\d\d)(\d\d)/;
    return "$3/$2/$1 - $4:$5:$6";
}

sub showProgress {
    my $msg = $_[0];
    my $status = defined $_[1] ? $_[1] : 0;
    if ($msg) {
        my $resp;
        $resp->{'status'} = $status;
        $resp->{'inprogress'} = $msg;
        $resp->{'msg'} = $msg;
        my $json = JSON::encode_json($resp);
        utf8::decode($json);

        glib_fildir_03::write_file($JS_FILE, $json);
    }
}

1;
